# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DiskReplicaGroupArgs', 'DiskReplicaGroup']

@pulumi.input_type
class DiskReplicaGroupArgs:
    def __init__(__self__, *,
                 destination_region_id: pulumi.Input[builtins.str],
                 destination_zone_id: pulumi.Input[builtins.str],
                 source_region_id: pulumi.Input[builtins.str],
                 source_zone_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disk_replica_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 one_shot: Optional[pulumi.Input[builtins.bool]] = None,
                 pair_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_replicate: Optional[pulumi.Input[builtins.bool]] = None,
                 rpo: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a DiskReplicaGroup resource.
        :param pulumi.Input[builtins.str] destination_region_id: The ID of the region to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] destination_zone_id: The ID of the zone to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] source_region_id: The ID of the region to which the production site belongs.
        :param pulumi.Input[builtins.str] source_zone_id: The ID of the zone to which the production site belongs.
        :param pulumi.Input[builtins.str] description: The description of the consistent replication group.
        :param pulumi.Input[builtins.str] disk_replica_group_name: Consistent replication group name.
        :param pulumi.Input[builtins.str] group_name: . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        :param pulumi.Input[builtins.bool] one_shot: Whether to synchronize immediately. Value range:
               - true: Start data synchronization immediately.
               - false: Data Synchronization starts after the RPO time period.
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] pair_ids: List of replication pair IDs contained in a consistent replication group.
        :param pulumi.Input[builtins.str] resource_group_id: resource group ID of enterprise
        :param pulumi.Input[builtins.bool] reverse_replicate: Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        :param pulumi.Input[builtins.int] rpo: The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        :param pulumi.Input[builtins.str] status: The status of the consistent replication group. Possible values:
               - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
               - creating: creating.
               - created: created.
               - create_failed: creation failed.
               - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
               - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
               - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
               - stopping: stopping.
               - stopped: stopped.
               - stop_failed: Stop failed.
               - Failover: failover.
               - Failed: failover completed.
               - failover_failed: failover failed.
               - Reprotection: In reverse copy operation.
               - reprotect_failed: reverse replication failed.
               - deleting: deleting.
               - delete_failed: delete failed.
               - deleted: deleted.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        pulumi.set(__self__, "destination_region_id", destination_region_id)
        pulumi.set(__self__, "destination_zone_id", destination_zone_id)
        pulumi.set(__self__, "source_region_id", source_region_id)
        pulumi.set(__self__, "source_zone_id", source_zone_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_replica_group_name is not None:
            pulumi.set(__self__, "disk_replica_group_name", disk_replica_group_name)
        if group_name is not None:
            warnings.warn("""Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""group_name is deprecated: Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""")
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if one_shot is not None:
            pulumi.set(__self__, "one_shot", one_shot)
        if pair_ids is not None:
            pulumi.set(__self__, "pair_ids", pair_ids)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if reverse_replicate is not None:
            pulumi.set(__self__, "reverse_replicate", reverse_replicate)
        if rpo is not None:
            pulumi.set(__self__, "rpo", rpo)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="destinationRegionId")
    def destination_region_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the region to which the disaster recovery site belongs.
        """
        return pulumi.get(self, "destination_region_id")

    @destination_region_id.setter
    def destination_region_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_region_id", value)

    @property
    @pulumi.getter(name="destinationZoneId")
    def destination_zone_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the zone to which the disaster recovery site belongs.
        """
        return pulumi.get(self, "destination_zone_id")

    @destination_zone_id.setter
    def destination_zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_zone_id", value)

    @property
    @pulumi.getter(name="sourceRegionId")
    def source_region_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the region to which the production site belongs.
        """
        return pulumi.get(self, "source_region_id")

    @source_region_id.setter
    def source_region_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_region_id", value)

    @property
    @pulumi.getter(name="sourceZoneId")
    def source_zone_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the zone to which the production site belongs.
        """
        return pulumi.get(self, "source_zone_id")

    @source_zone_id.setter
    def source_zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_zone_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the consistent replication group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskReplicaGroupName")
    def disk_replica_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consistent replication group name.
        """
        return pulumi.get(self, "disk_replica_group_name")

    @disk_replica_group_name.setter
    def disk_replica_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disk_replica_group_name", value)

    @property
    @pulumi.getter(name="groupName")
    @_utilities.deprecated("""Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="oneShot")
    def one_shot(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to synchronize immediately. Value range:
        - true: Start data synchronization immediately.
        - false: Data Synchronization starts after the RPO time period.

        Default value: false.
        """
        return pulumi.get(self, "one_shot")

    @one_shot.setter
    def one_shot(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "one_shot", value)

    @property
    @pulumi.getter(name="pairIds")
    def pair_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of replication pair IDs contained in a consistent replication group.
        """
        return pulumi.get(self, "pair_ids")

    @pair_ids.setter
    def pair_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "pair_ids", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        resource group ID of enterprise
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="reverseReplicate")
    def reverse_replicate(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        """
        return pulumi.get(self, "reverse_replicate")

    @reverse_replicate.setter
    def reverse_replicate(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "reverse_replicate", value)

    @property
    @pulumi.getter
    def rpo(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        """
        return pulumi.get(self, "rpo")

    @rpo.setter
    def rpo(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "rpo", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the consistent replication group. Possible values:
        - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
        - creating: creating.
        - created: created.
        - create_failed: creation failed.
        - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
        - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
        - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
        - stopping: stopping.
        - stopped: stopped.
        - stop_failed: Stop failed.
        - Failover: failover.
        - Failed: failover completed.
        - failover_failed: failover failed.
        - Reprotection: In reverse copy operation.
        - reprotect_failed: reverse replication failed.
        - deleting: deleting.
        - delete_failed: delete failed.
        - deleted: deleted.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _DiskReplicaGroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 destination_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 disk_replica_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 one_shot: Optional[pulumi.Input[builtins.bool]] = None,
                 pair_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_replicate: Optional[pulumi.Input[builtins.bool]] = None,
                 rpo: Optional[pulumi.Input[builtins.int]] = None,
                 source_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering DiskReplicaGroup resources.
        :param pulumi.Input[builtins.str] description: The description of the consistent replication group.
        :param pulumi.Input[builtins.str] destination_region_id: The ID of the region to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] destination_zone_id: The ID of the zone to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] disk_replica_group_name: Consistent replication group name.
        :param pulumi.Input[builtins.str] group_name: . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        :param pulumi.Input[builtins.bool] one_shot: Whether to synchronize immediately. Value range:
               - true: Start data synchronization immediately.
               - false: Data Synchronization starts after the RPO time period.
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] pair_ids: List of replication pair IDs contained in a consistent replication group.
        :param pulumi.Input[builtins.str] resource_group_id: resource group ID of enterprise
        :param pulumi.Input[builtins.bool] reverse_replicate: Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        :param pulumi.Input[builtins.int] rpo: The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        :param pulumi.Input[builtins.str] source_region_id: The ID of the region to which the production site belongs.
        :param pulumi.Input[builtins.str] source_zone_id: The ID of the zone to which the production site belongs.
        :param pulumi.Input[builtins.str] status: The status of the consistent replication group. Possible values:
               - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
               - creating: creating.
               - created: created.
               - create_failed: creation failed.
               - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
               - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
               - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
               - stopping: stopping.
               - stopped: stopped.
               - stop_failed: Stop failed.
               - Failover: failover.
               - Failed: failover completed.
               - failover_failed: failover failed.
               - Reprotection: In reverse copy operation.
               - reprotect_failed: reverse replication failed.
               - deleting: deleting.
               - delete_failed: delete failed.
               - deleted: deleted.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_region_id is not None:
            pulumi.set(__self__, "destination_region_id", destination_region_id)
        if destination_zone_id is not None:
            pulumi.set(__self__, "destination_zone_id", destination_zone_id)
        if disk_replica_group_name is not None:
            pulumi.set(__self__, "disk_replica_group_name", disk_replica_group_name)
        if group_name is not None:
            warnings.warn("""Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""group_name is deprecated: Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""")
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if one_shot is not None:
            pulumi.set(__self__, "one_shot", one_shot)
        if pair_ids is not None:
            pulumi.set(__self__, "pair_ids", pair_ids)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if reverse_replicate is not None:
            pulumi.set(__self__, "reverse_replicate", reverse_replicate)
        if rpo is not None:
            pulumi.set(__self__, "rpo", rpo)
        if source_region_id is not None:
            pulumi.set(__self__, "source_region_id", source_region_id)
        if source_zone_id is not None:
            pulumi.set(__self__, "source_zone_id", source_zone_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the consistent replication group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationRegionId")
    def destination_region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the region to which the disaster recovery site belongs.
        """
        return pulumi.get(self, "destination_region_id")

    @destination_region_id.setter
    def destination_region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_region_id", value)

    @property
    @pulumi.getter(name="destinationZoneId")
    def destination_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the zone to which the disaster recovery site belongs.
        """
        return pulumi.get(self, "destination_zone_id")

    @destination_zone_id.setter
    def destination_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_zone_id", value)

    @property
    @pulumi.getter(name="diskReplicaGroupName")
    def disk_replica_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Consistent replication group name.
        """
        return pulumi.get(self, "disk_replica_group_name")

    @disk_replica_group_name.setter
    def disk_replica_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disk_replica_group_name", value)

    @property
    @pulumi.getter(name="groupName")
    @_utilities.deprecated("""Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="oneShot")
    def one_shot(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to synchronize immediately. Value range:
        - true: Start data synchronization immediately.
        - false: Data Synchronization starts after the RPO time period.

        Default value: false.
        """
        return pulumi.get(self, "one_shot")

    @one_shot.setter
    def one_shot(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "one_shot", value)

    @property
    @pulumi.getter(name="pairIds")
    def pair_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of replication pair IDs contained in a consistent replication group.
        """
        return pulumi.get(self, "pair_ids")

    @pair_ids.setter
    def pair_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "pair_ids", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        resource group ID of enterprise
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="reverseReplicate")
    def reverse_replicate(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        """
        return pulumi.get(self, "reverse_replicate")

    @reverse_replicate.setter
    def reverse_replicate(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "reverse_replicate", value)

    @property
    @pulumi.getter
    def rpo(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        """
        return pulumi.get(self, "rpo")

    @rpo.setter
    def rpo(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "rpo", value)

    @property
    @pulumi.getter(name="sourceRegionId")
    def source_region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the region to which the production site belongs.
        """
        return pulumi.get(self, "source_region_id")

    @source_region_id.setter
    def source_region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_region_id", value)

    @property
    @pulumi.getter(name="sourceZoneId")
    def source_zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the zone to which the production site belongs.
        """
        return pulumi.get(self, "source_zone_id")

    @source_zone_id.setter
    def source_zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_zone_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the consistent replication group. Possible values:
        - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
        - creating: creating.
        - created: created.
        - create_failed: creation failed.
        - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
        - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
        - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
        - stopping: stopping.
        - stopped: stopped.
        - stop_failed: Stop failed.
        - Failover: failover.
        - Failed: failover completed.
        - failover_failed: failover failed.
        - Reprotection: In reverse copy operation.
        - reprotect_failed: reverse replication failed.
        - deleting: deleting.
        - delete_failed: delete failed.
        - deleted: deleted.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("alicloud:ebs/diskReplicaGroup:DiskReplicaGroup")
class DiskReplicaGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 destination_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 disk_replica_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 one_shot: Optional[pulumi.Input[builtins.bool]] = None,
                 pair_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_replicate: Optional[pulumi.Input[builtins.bool]] = None,
                 rpo: Optional[pulumi.Input[builtins.int]] = None,
                 source_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Elastic Block Storage(EBS) Disk Replica Group resource.

        consistent replica group.

        For information about Elastic Block Storage(EBS) Disk Replica Group and how to use it, see [What is Disk Replica Group](https://www.alibabacloud.com/help/en/elastic-compute-service/latest/creatediskreplicagroup).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_regions(current=True)
        default_get_regions = alicloud.ebs.get_regions(region_id=default.regions[0].id)
        default_disk_replica_group = alicloud.ebs.DiskReplicaGroup("default",
            source_region_id=default.regions[0].id,
            source_zone_id=default_get_regions.regions[0].zones[0].zone_id,
            destination_region_id=default.regions[0].id,
            destination_zone_id=default_get_regions.regions[0].zones[1].zone_id,
            group_name=name,
            description=name,
            rpo=900)
        ```

        ## Import

        Elastic Block Storage(EBS) Disk Replica Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ebs/diskReplicaGroup:DiskReplicaGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: The description of the consistent replication group.
        :param pulumi.Input[builtins.str] destination_region_id: The ID of the region to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] destination_zone_id: The ID of the zone to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] disk_replica_group_name: Consistent replication group name.
        :param pulumi.Input[builtins.str] group_name: . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        :param pulumi.Input[builtins.bool] one_shot: Whether to synchronize immediately. Value range:
               - true: Start data synchronization immediately.
               - false: Data Synchronization starts after the RPO time period.
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] pair_ids: List of replication pair IDs contained in a consistent replication group.
        :param pulumi.Input[builtins.str] resource_group_id: resource group ID of enterprise
        :param pulumi.Input[builtins.bool] reverse_replicate: Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        :param pulumi.Input[builtins.int] rpo: The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        :param pulumi.Input[builtins.str] source_region_id: The ID of the region to which the production site belongs.
        :param pulumi.Input[builtins.str] source_zone_id: The ID of the zone to which the production site belongs.
        :param pulumi.Input[builtins.str] status: The status of the consistent replication group. Possible values:
               - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
               - creating: creating.
               - created: created.
               - create_failed: creation failed.
               - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
               - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
               - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
               - stopping: stopping.
               - stopped: stopped.
               - stop_failed: Stop failed.
               - Failover: failover.
               - Failed: failover completed.
               - failover_failed: failover failed.
               - Reprotection: In reverse copy operation.
               - reprotect_failed: reverse replication failed.
               - deleting: deleting.
               - delete_failed: delete failed.
               - deleted: deleted.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DiskReplicaGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Elastic Block Storage(EBS) Disk Replica Group resource.

        consistent replica group.

        For information about Elastic Block Storage(EBS) Disk Replica Group and how to use it, see [What is Disk Replica Group](https://www.alibabacloud.com/help/en/elastic-compute-service/latest/creatediskreplicagroup).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_regions(current=True)
        default_get_regions = alicloud.ebs.get_regions(region_id=default.regions[0].id)
        default_disk_replica_group = alicloud.ebs.DiskReplicaGroup("default",
            source_region_id=default.regions[0].id,
            source_zone_id=default_get_regions.regions[0].zones[0].zone_id,
            destination_region_id=default.regions[0].id,
            destination_zone_id=default_get_regions.regions[0].zones[1].zone_id,
            group_name=name,
            description=name,
            rpo=900)
        ```

        ## Import

        Elastic Block Storage(EBS) Disk Replica Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ebs/diskReplicaGroup:DiskReplicaGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param DiskReplicaGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DiskReplicaGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 destination_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 disk_replica_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 one_shot: Optional[pulumi.Input[builtins.bool]] = None,
                 pair_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_replicate: Optional[pulumi.Input[builtins.bool]] = None,
                 rpo: Optional[pulumi.Input[builtins.int]] = None,
                 source_region_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DiskReplicaGroupArgs.__new__(DiskReplicaGroupArgs)

            __props__.__dict__["description"] = description
            if destination_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'destination_region_id'")
            __props__.__dict__["destination_region_id"] = destination_region_id
            if destination_zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'destination_zone_id'")
            __props__.__dict__["destination_zone_id"] = destination_zone_id
            __props__.__dict__["disk_replica_group_name"] = disk_replica_group_name
            __props__.__dict__["group_name"] = group_name
            __props__.__dict__["one_shot"] = one_shot
            __props__.__dict__["pair_ids"] = pair_ids
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["reverse_replicate"] = reverse_replicate
            __props__.__dict__["rpo"] = rpo
            if source_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_region_id'")
            __props__.__dict__["source_region_id"] = source_region_id
            if source_zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_zone_id'")
            __props__.__dict__["source_zone_id"] = source_zone_id
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
        super(DiskReplicaGroup, __self__).__init__(
            'alicloud:ebs/diskReplicaGroup:DiskReplicaGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            destination_region_id: Optional[pulumi.Input[builtins.str]] = None,
            destination_zone_id: Optional[pulumi.Input[builtins.str]] = None,
            disk_replica_group_name: Optional[pulumi.Input[builtins.str]] = None,
            group_name: Optional[pulumi.Input[builtins.str]] = None,
            one_shot: Optional[pulumi.Input[builtins.bool]] = None,
            pair_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            reverse_replicate: Optional[pulumi.Input[builtins.bool]] = None,
            rpo: Optional[pulumi.Input[builtins.int]] = None,
            source_region_id: Optional[pulumi.Input[builtins.str]] = None,
            source_zone_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'DiskReplicaGroup':
        """
        Get an existing DiskReplicaGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: The description of the consistent replication group.
        :param pulumi.Input[builtins.str] destination_region_id: The ID of the region to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] destination_zone_id: The ID of the zone to which the disaster recovery site belongs.
        :param pulumi.Input[builtins.str] disk_replica_group_name: Consistent replication group name.
        :param pulumi.Input[builtins.str] group_name: . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        :param pulumi.Input[builtins.bool] one_shot: Whether to synchronize immediately. Value range:
               - true: Start data synchronization immediately.
               - false: Data Synchronization starts after the RPO time period.
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] pair_ids: List of replication pair IDs contained in a consistent replication group.
        :param pulumi.Input[builtins.str] resource_group_id: resource group ID of enterprise
        :param pulumi.Input[builtins.bool] reverse_replicate: Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        :param pulumi.Input[builtins.int] rpo: The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        :param pulumi.Input[builtins.str] source_region_id: The ID of the region to which the production site belongs.
        :param pulumi.Input[builtins.str] source_zone_id: The ID of the zone to which the production site belongs.
        :param pulumi.Input[builtins.str] status: The status of the consistent replication group. Possible values:
               - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
               - creating: creating.
               - created: created.
               - create_failed: creation failed.
               - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
               - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
               - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
               - stopping: stopping.
               - stopped: stopped.
               - stop_failed: Stop failed.
               - Failover: failover.
               - Failed: failover completed.
               - failover_failed: failover failed.
               - Reprotection: In reverse copy operation.
               - reprotect_failed: reverse replication failed.
               - deleting: deleting.
               - delete_failed: delete failed.
               - deleted: deleted.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DiskReplicaGroupState.__new__(_DiskReplicaGroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination_region_id"] = destination_region_id
        __props__.__dict__["destination_zone_id"] = destination_zone_id
        __props__.__dict__["disk_replica_group_name"] = disk_replica_group_name
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["one_shot"] = one_shot
        __props__.__dict__["pair_ids"] = pair_ids
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["reverse_replicate"] = reverse_replicate
        __props__.__dict__["rpo"] = rpo
        __props__.__dict__["source_region_id"] = source_region_id
        __props__.__dict__["source_zone_id"] = source_zone_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return DiskReplicaGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the consistent replication group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationRegionId")
    def destination_region_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the region to which the disaster recovery site belongs.
        """
        return pulumi.get(self, "destination_region_id")

    @property
    @pulumi.getter(name="destinationZoneId")
    def destination_zone_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the zone to which the disaster recovery site belongs.
        """
        return pulumi.get(self, "destination_zone_id")

    @property
    @pulumi.getter(name="diskReplicaGroupName")
    def disk_replica_group_name(self) -> pulumi.Output[builtins.str]:
        """
        Consistent replication group name.
        """
        return pulumi.get(self, "disk_replica_group_name")

    @property
    @pulumi.getter(name="groupName")
    @_utilities.deprecated("""Field 'group_name' has been deprecated since provider version 1.245.0. New field 'disk_replica_group_name' instead.""")
    def group_name(self) -> pulumi.Output[builtins.str]:
        """
        . Field 'group_name' has been deprecated from provider version 1.245.0. New field 'disk_replica_group_name' instead.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="oneShot")
    def one_shot(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to synchronize immediately. Value range:
        - true: Start data synchronization immediately.
        - false: Data Synchronization starts after the RPO time period.

        Default value: false.
        """
        return pulumi.get(self, "one_shot")

    @property
    @pulumi.getter(name="pairIds")
    def pair_ids(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of replication pair IDs contained in a consistent replication group.
        """
        return pulumi.get(self, "pair_ids")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        resource group ID of enterprise
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="reverseReplicate")
    def reverse_replicate(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to enable the reverse replication sub-feature. Valid values: true and false. Default value: true.
        """
        return pulumi.get(self, "reverse_replicate")

    @property
    @pulumi.getter
    def rpo(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The RPO value set by the consistency group in seconds. Currently only 900 seconds are supported.
        """
        return pulumi.get(self, "rpo")

    @property
    @pulumi.getter(name="sourceRegionId")
    def source_region_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the region to which the production site belongs.
        """
        return pulumi.get(self, "source_region_id")

    @property
    @pulumi.getter(name="sourceZoneId")
    def source_zone_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the zone to which the production site belongs.
        """
        return pulumi.get(self, "source_zone_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the consistent replication group. Possible values:
        - invalid: invalid. This state indicates that there is an exception to the replication pair in the consistent replication group.
        - creating: creating.
        - created: created.
        - create_failed: creation failed.
        - manual_syncing: in a single synchronization. If it is the first single synchronization, this status is also displayed in the synchronization.
        - syncing: synchronization. This state is the first time data is copied asynchronously between the master and slave disks.
        - normal: normal. When data replication is completed within the current cycle of asynchronous replication, it will be in this state.
        - stopping: stopping.
        - stopped: stopped.
        - stop_failed: Stop failed.
        - Failover: failover.
        - Failed: failover completed.
        - failover_failed: failover failed.
        - Reprotection: In reverse copy operation.
        - reprotect_failed: reverse replication failed.
        - deleting: deleting.
        - delete_failed: delete failed.
        - deleted: deleted.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['QuotaScheduleArgs', 'QuotaSchedule']

@pulumi.input_type
class QuotaScheduleArgs:
    def __init__(__self__, *,
                 nickname: pulumi.Input[builtins.str],
                 timezone: pulumi.Input[builtins.str],
                 schedule_lists: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]]] = None):
        """
        The set of arguments for constructing a QuotaSchedule resource.
        :param pulumi.Input[builtins.str] nickname: The nickname of level-1 compute quota.
        :param pulumi.Input[builtins.str] timezone: Time zone, reference value: UTC +8
        :param pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]] schedule_lists: schedule list See `schedule_list` below.
        """
        pulumi.set(__self__, "nickname", nickname)
        pulumi.set(__self__, "timezone", timezone)
        if schedule_lists is not None:
            pulumi.set(__self__, "schedule_lists", schedule_lists)

    @property
    @pulumi.getter
    def nickname(self) -> pulumi.Input[builtins.str]:
        """
        The nickname of level-1 compute quota.
        """
        return pulumi.get(self, "nickname")

    @nickname.setter
    def nickname(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nickname", value)

    @property
    @pulumi.getter
    def timezone(self) -> pulumi.Input[builtins.str]:
        """
        Time zone, reference value: UTC +8
        """
        return pulumi.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "timezone", value)

    @property
    @pulumi.getter(name="scheduleLists")
    def schedule_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]]]:
        """
        schedule list See `schedule_list` below.
        """
        return pulumi.get(self, "schedule_lists")

    @schedule_lists.setter
    def schedule_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]]]):
        pulumi.set(self, "schedule_lists", value)


@pulumi.input_type
class _QuotaScheduleState:
    def __init__(__self__, *,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 schedule_lists: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering QuotaSchedule resources.
        :param pulumi.Input[builtins.str] nickname: The nickname of level-1 compute quota.
        :param pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]] schedule_lists: schedule list See `schedule_list` below.
        :param pulumi.Input[builtins.str] timezone: Time zone, reference value: UTC +8
        """
        if nickname is not None:
            pulumi.set(__self__, "nickname", nickname)
        if schedule_lists is not None:
            pulumi.set(__self__, "schedule_lists", schedule_lists)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)

    @property
    @pulumi.getter
    def nickname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The nickname of level-1 compute quota.
        """
        return pulumi.get(self, "nickname")

    @nickname.setter
    def nickname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nickname", value)

    @property
    @pulumi.getter(name="scheduleLists")
    def schedule_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]]]:
        """
        schedule list See `schedule_list` below.
        """
        return pulumi.get(self, "schedule_lists")

    @schedule_lists.setter
    def schedule_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QuotaScheduleScheduleListArgs']]]]):
        pulumi.set(self, "schedule_lists", value)

    @property
    @pulumi.getter
    def timezone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time zone, reference value: UTC +8
        """
        return pulumi.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "timezone", value)


@pulumi.type_token("alicloud:maxcompute/quotaSchedule:QuotaSchedule")
class QuotaSchedule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 schedule_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QuotaScheduleScheduleListArgs', 'QuotaScheduleScheduleListArgsDict']]]]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        Max Compute Quota Schedule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/quotaSchedule:QuotaSchedule example <nickname>:<timezone>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] nickname: The nickname of level-1 compute quota.
        :param pulumi.Input[Sequence[pulumi.Input[Union['QuotaScheduleScheduleListArgs', 'QuotaScheduleScheduleListArgsDict']]]] schedule_lists: schedule list See `schedule_list` below.
        :param pulumi.Input[builtins.str] timezone: Time zone, reference value: UTC +8
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaScheduleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Max Compute Quota Schedule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/quotaSchedule:QuotaSchedule example <nickname>:<timezone>
        ```

        :param str resource_name: The name of the resource.
        :param QuotaScheduleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaScheduleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 schedule_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QuotaScheduleScheduleListArgs', 'QuotaScheduleScheduleListArgsDict']]]]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaScheduleArgs.__new__(QuotaScheduleArgs)

            if nickname is None and not opts.urn:
                raise TypeError("Missing required property 'nickname'")
            __props__.__dict__["nickname"] = nickname
            __props__.__dict__["schedule_lists"] = schedule_lists
            if timezone is None and not opts.urn:
                raise TypeError("Missing required property 'timezone'")
            __props__.__dict__["timezone"] = timezone
        super(QuotaSchedule, __self__).__init__(
            'alicloud:maxcompute/quotaSchedule:QuotaSchedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            nickname: Optional[pulumi.Input[builtins.str]] = None,
            schedule_lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QuotaScheduleScheduleListArgs', 'QuotaScheduleScheduleListArgsDict']]]]] = None,
            timezone: Optional[pulumi.Input[builtins.str]] = None) -> 'QuotaSchedule':
        """
        Get an existing QuotaSchedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] nickname: The nickname of level-1 compute quota.
        :param pulumi.Input[Sequence[pulumi.Input[Union['QuotaScheduleScheduleListArgs', 'QuotaScheduleScheduleListArgsDict']]]] schedule_lists: schedule list See `schedule_list` below.
        :param pulumi.Input[builtins.str] timezone: Time zone, reference value: UTC +8
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaScheduleState.__new__(_QuotaScheduleState)

        __props__.__dict__["nickname"] = nickname
        __props__.__dict__["schedule_lists"] = schedule_lists
        __props__.__dict__["timezone"] = timezone
        return QuotaSchedule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def nickname(self) -> pulumi.Output[builtins.str]:
        """
        The nickname of level-1 compute quota.
        """
        return pulumi.get(self, "nickname")

    @property
    @pulumi.getter(name="scheduleLists")
    def schedule_lists(self) -> pulumi.Output[Optional[Sequence['outputs.QuotaScheduleScheduleList']]]:
        """
        schedule list See `schedule_list` below.
        """
        return pulumi.get(self, "schedule_lists")

    @property
    @pulumi.getter
    def timezone(self) -> pulumi.Output[builtins.str]:
        """
        Time zone, reference value: UTC +8
        """
        return pulumi.get(self, "timezone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEcsListArgs',
    'InstanceEcsListArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceEcsListArgsDict(TypedDict):
        ecs_id: NotRequired[pulumi.Input[builtins.str]]
        """
        The ID of the ECS instance.
        """
elif False:
    InstanceEcsListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEcsListArgs:
    def __init__(__self__, *,
                 ecs_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] ecs_id: The ID of the ECS instance.
        """
        if ecs_id is not None:
            pulumi.set(__self__, "ecs_id", ecs_id)

    @property
    @pulumi.getter(name="ecsId")
    def ecs_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the ECS instance.
        """
        return pulumi.get(self, "ecs_id")

    @ecs_id.setter
    def ecs_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ecs_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpcEndpointServiceUsersResult',
    'AwaitableGetVpcEndpointServiceUsersResult',
    'get_vpc_endpoint_service_users',
    'get_vpc_endpoint_service_users_output',
]

@pulumi.output_type
class GetVpcEndpointServiceUsersResult:
    """
    A collection of values returned by getVpcEndpointServiceUsers.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, service_id=None, user_id=None, users=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if service_id and not isinstance(service_id, str):
            raise TypeError("Expected argument 'service_id' to be a str")
        pulumi.set(__self__, "service_id", service_id)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Vpc Endpoint Service User IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> builtins.str:
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[builtins.str]:
        """
        The Id of Ram User.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetVpcEndpointServiceUsersUserResult']:
        """
        A list of Privatelink Vpc Endpoint Service Users. Each element contains the following attributes:
        """
        return pulumi.get(self, "users")


class AwaitableGetVpcEndpointServiceUsersResult(GetVpcEndpointServiceUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcEndpointServiceUsersResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            service_id=self.service_id,
            user_id=self.user_id,
            users=self.users)


def get_vpc_endpoint_service_users(output_file: Optional[builtins.str] = None,
                                   service_id: Optional[builtins.str] = None,
                                   user_id: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcEndpointServiceUsersResult:
    """
    This data source provides the Privatelink Vpc Endpoint Service Users of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.110.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.privatelink.get_vpc_endpoint_service_users(service_id="epsrv-gw81c6vxxxxxx")
    pulumi.export("firstPrivatelinkVpcEndpointServiceUserId", example.users[0].id)
    ```


    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str service_id: The Id of Vpc Endpoint Service.
    :param builtins.str user_id: The Id of Ram User.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['serviceId'] = service_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:privatelink/getVpcEndpointServiceUsers:getVpcEndpointServiceUsers', __args__, opts=opts, typ=GetVpcEndpointServiceUsersResult).value

    return AwaitableGetVpcEndpointServiceUsersResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        service_id=pulumi.get(__ret__, 'service_id'),
        user_id=pulumi.get(__ret__, 'user_id'),
        users=pulumi.get(__ret__, 'users'))
def get_vpc_endpoint_service_users_output(output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                          service_id: Optional[pulumi.Input[builtins.str]] = None,
                                          user_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpcEndpointServiceUsersResult]:
    """
    This data source provides the Privatelink Vpc Endpoint Service Users of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.110.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.privatelink.get_vpc_endpoint_service_users(service_id="epsrv-gw81c6vxxxxxx")
    pulumi.export("firstPrivatelinkVpcEndpointServiceUserId", example.users[0].id)
    ```


    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str service_id: The Id of Vpc Endpoint Service.
    :param builtins.str user_id: The Id of Ram User.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['serviceId'] = service_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:privatelink/getVpcEndpointServiceUsers:getVpcEndpointServiceUsers', __args__, opts=opts, typ=GetVpcEndpointServiceUsersResult)
    return __ret__.apply(lambda __response__: GetVpcEndpointServiceUsersResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        service_id=pulumi.get(__response__, 'service_id'),
        user_id=pulumi.get(__response__, 'user_id'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CertificateArgs', 'Certificate']

@pulumi.input_type
class CertificateArgs:
    def __init__(__self__, *,
                 created_type: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 cas_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Certificate resource.
        :param pulumi.Input[builtins.str] created_type: The certificate type.
               - cas (Certificate Center Certificate)
               - upload (custom upload certificate)
               - free( Free certificate).
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites interface.
        :param pulumi.Input[builtins.str] cas_id: Cloud certificate ID.
        :param pulumi.Input[builtins.str] cert_id: The certificate Id.
        :param pulumi.Input[builtins.str] cert_name: The certificate name.
        :param pulumi.Input[builtins.str] certificate: The certificate type. Valid values:
               
               - cas: a certificate purchased by using Certificate Management Service.
               - upload: a custom certificate that you upload.
        :param pulumi.Input[builtins.str] domains: A list of domain names. Multiple domain names are separated by commas.
        :param pulumi.Input[builtins.str] private_key: The certificate private key.
        :param pulumi.Input[builtins.str] region: Geographical information.
        :param pulumi.Input[builtins.str] type: Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        pulumi.set(__self__, "created_type", created_type)
        pulumi.set(__self__, "site_id", site_id)
        if cas_id is not None:
            pulumi.set(__self__, "cas_id", cas_id)
        if cert_id is not None:
            pulumi.set(__self__, "cert_id", cert_id)
        if cert_name is not None:
            pulumi.set(__self__, "cert_name", cert_name)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if domains is not None:
            pulumi.set(__self__, "domains", domains)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="createdType")
    def created_type(self) -> pulumi.Input[builtins.str]:
        """
        The certificate type.
        - cas (Certificate Center Certificate)
        - upload (custom upload certificate)
        - free( Free certificate).
        """
        return pulumi.get(self, "created_type")

    @created_type.setter
    def created_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "created_type", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="casId")
    def cas_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cloud certificate ID.
        """
        return pulumi.get(self, "cas_id")

    @cas_id.setter
    def cas_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cas_id", value)

    @property
    @pulumi.getter(name="certId")
    def cert_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate Id.
        """
        return pulumi.get(self, "cert_id")

    @cert_id.setter
    def cert_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cert_id", value)

    @property
    @pulumi.getter(name="certName")
    def cert_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate name.
        """
        return pulumi.get(self, "cert_name")

    @cert_name.setter
    def cert_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cert_name", value)

    @property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate type. Valid values:

        - cas: a certificate purchased by using Certificate Management Service.
        - upload: a custom certificate that you upload.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter
    def domains(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A list of domain names. Multiple domain names are separated by commas.
        """
        return pulumi.get(self, "domains")

    @domains.setter
    def domains(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domains", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate private key.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Geographical information.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _CertificateState:
    def __init__(__self__, *,
                 cas_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 created_type: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Certificate resources.
        :param pulumi.Input[builtins.str] cas_id: Cloud certificate ID.
        :param pulumi.Input[builtins.str] cert_id: The certificate Id.
        :param pulumi.Input[builtins.str] cert_name: The certificate name.
        :param pulumi.Input[builtins.str] certificate: The certificate type. Valid values:
               
               - cas: a certificate purchased by using Certificate Management Service.
               - upload: a custom certificate that you upload.
        :param pulumi.Input[builtins.str] create_time: Creation time.
        :param pulumi.Input[builtins.str] created_type: The certificate type.
               - cas (Certificate Center Certificate)
               - upload (custom upload certificate)
               - free( Free certificate).
        :param pulumi.Input[builtins.str] domains: A list of domain names. Multiple domain names are separated by commas.
        :param pulumi.Input[builtins.str] private_key: The certificate private key.
        :param pulumi.Input[builtins.str] region: Geographical information.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites interface.
        :param pulumi.Input[builtins.str] status: Certificate status.(within 30 days).- issued.- applying.- application failed.- canceled.
        :param pulumi.Input[builtins.str] type: Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        if cas_id is not None:
            pulumi.set(__self__, "cas_id", cas_id)
        if cert_id is not None:
            pulumi.set(__self__, "cert_id", cert_id)
        if cert_name is not None:
            pulumi.set(__self__, "cert_name", cert_name)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if created_type is not None:
            pulumi.set(__self__, "created_type", created_type)
        if domains is not None:
            pulumi.set(__self__, "domains", domains)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="casId")
    def cas_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cloud certificate ID.
        """
        return pulumi.get(self, "cas_id")

    @cas_id.setter
    def cas_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cas_id", value)

    @property
    @pulumi.getter(name="certId")
    def cert_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate Id.
        """
        return pulumi.get(self, "cert_id")

    @cert_id.setter
    def cert_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cert_id", value)

    @property
    @pulumi.getter(name="certName")
    def cert_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate name.
        """
        return pulumi.get(self, "cert_name")

    @cert_name.setter
    def cert_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cert_name", value)

    @property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate type. Valid values:

        - cas: a certificate purchased by using Certificate Management Service.
        - upload: a custom certificate that you upload.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="createdType")
    def created_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate type.
        - cas (Certificate Center Certificate)
        - upload (custom upload certificate)
        - free( Free certificate).
        """
        return pulumi.get(self, "created_type")

    @created_type.setter
    def created_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_type", value)

    @property
    @pulumi.getter
    def domains(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A list of domain names. Multiple domain names are separated by commas.
        """
        return pulumi.get(self, "domains")

    @domains.setter
    def domains(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domains", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate private key.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Geographical information.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the ListSites interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate status.(within 30 days).- issued.- applying.- application failed.- canceled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("alicloud:esa/certificate:Certificate")
class Certificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cas_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 created_type: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Certificate resource.

        For information about ESA Certificate and how to use it, see [What is Certificate](https://next.api.alibabacloud.com/document/ESA/2024-09-10/SetCertificate).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan",
            site_name="gositecdn.cn")
        default_certificate = alicloud.esa.Certificate("default",
            created_type="free",
            domains="101.gositecdn.cn",
            site_id=default.sites[0].id,
            type="lets_encrypt")
        ```

        ## Import

        ESA Certificate can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/certificate:Certificate example <site_id>:<cert_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cas_id: Cloud certificate ID.
        :param pulumi.Input[builtins.str] cert_id: The certificate Id.
        :param pulumi.Input[builtins.str] cert_name: The certificate name.
        :param pulumi.Input[builtins.str] certificate: The certificate type. Valid values:
               
               - cas: a certificate purchased by using Certificate Management Service.
               - upload: a custom certificate that you upload.
        :param pulumi.Input[builtins.str] created_type: The certificate type.
               - cas (Certificate Center Certificate)
               - upload (custom upload certificate)
               - free( Free certificate).
        :param pulumi.Input[builtins.str] domains: A list of domain names. Multiple domain names are separated by commas.
        :param pulumi.Input[builtins.str] private_key: The certificate private key.
        :param pulumi.Input[builtins.str] region: Geographical information.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites interface.
        :param pulumi.Input[builtins.str] type: Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Certificate resource.

        For information about ESA Certificate and how to use it, see [What is Certificate](https://next.api.alibabacloud.com/document/ESA/2024-09-10/SetCertificate).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan",
            site_name="gositecdn.cn")
        default_certificate = alicloud.esa.Certificate("default",
            created_type="free",
            domains="101.gositecdn.cn",
            site_id=default.sites[0].id,
            type="lets_encrypt")
        ```

        ## Import

        ESA Certificate can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/certificate:Certificate example <site_id>:<cert_id>
        ```

        :param str resource_name: The name of the resource.
        :param CertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cas_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_id: Optional[pulumi.Input[builtins.str]] = None,
                 cert_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate: Optional[pulumi.Input[builtins.str]] = None,
                 created_type: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CertificateArgs.__new__(CertificateArgs)

            __props__.__dict__["cas_id"] = cas_id
            __props__.__dict__["cert_id"] = cert_id
            __props__.__dict__["cert_name"] = cert_name
            __props__.__dict__["certificate"] = certificate
            if created_type is None and not opts.urn:
                raise TypeError("Missing required property 'created_type'")
            __props__.__dict__["created_type"] = created_type
            __props__.__dict__["domains"] = domains
            __props__.__dict__["private_key"] = private_key
            __props__.__dict__["region"] = region
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["type"] = type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Certificate, __self__).__init__(
            'alicloud:esa/certificate:Certificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cas_id: Optional[pulumi.Input[builtins.str]] = None,
            cert_id: Optional[pulumi.Input[builtins.str]] = None,
            cert_name: Optional[pulumi.Input[builtins.str]] = None,
            certificate: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            created_type: Optional[pulumi.Input[builtins.str]] = None,
            domains: Optional[pulumi.Input[builtins.str]] = None,
            private_key: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Certificate':
        """
        Get an existing Certificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cas_id: Cloud certificate ID.
        :param pulumi.Input[builtins.str] cert_id: The certificate Id.
        :param pulumi.Input[builtins.str] cert_name: The certificate name.
        :param pulumi.Input[builtins.str] certificate: The certificate type. Valid values:
               
               - cas: a certificate purchased by using Certificate Management Service.
               - upload: a custom certificate that you upload.
        :param pulumi.Input[builtins.str] create_time: Creation time.
        :param pulumi.Input[builtins.str] created_type: The certificate type.
               - cas (Certificate Center Certificate)
               - upload (custom upload certificate)
               - free( Free certificate).
        :param pulumi.Input[builtins.str] domains: A list of domain names. Multiple domain names are separated by commas.
        :param pulumi.Input[builtins.str] private_key: The certificate private key.
        :param pulumi.Input[builtins.str] region: Geographical information.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites interface.
        :param pulumi.Input[builtins.str] status: Certificate status.(within 30 days).- issued.- applying.- application failed.- canceled.
        :param pulumi.Input[builtins.str] type: Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CertificateState.__new__(_CertificateState)

        __props__.__dict__["cas_id"] = cas_id
        __props__.__dict__["cert_id"] = cert_id
        __props__.__dict__["cert_name"] = cert_name
        __props__.__dict__["certificate"] = certificate
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["created_type"] = created_type
        __props__.__dict__["domains"] = domains
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["region"] = region
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return Certificate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="casId")
    def cas_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cloud certificate ID.
        """
        return pulumi.get(self, "cas_id")

    @property
    @pulumi.getter(name="certId")
    def cert_id(self) -> pulumi.Output[builtins.str]:
        """
        The certificate Id.
        """
        return pulumi.get(self, "cert_id")

    @property
    @pulumi.getter(name="certName")
    def cert_name(self) -> pulumi.Output[builtins.str]:
        """
        The certificate name.
        """
        return pulumi.get(self, "cert_name")

    @property
    @pulumi.getter
    def certificate(self) -> pulumi.Output[builtins.str]:
        """
        The certificate type. Valid values:

        - cas: a certificate purchased by using Certificate Management Service.
        - upload: a custom certificate that you upload.
        """
        return pulumi.get(self, "certificate")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createdType")
    def created_type(self) -> pulumi.Output[builtins.str]:
        """
        The certificate type.
        - cas (Certificate Center Certificate)
        - upload (custom upload certificate)
        - free( Free certificate).
        """
        return pulumi.get(self, "created_type")

    @property
    @pulumi.getter
    def domains(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A list of domain names. Multiple domain names are separated by commas.
        """
        return pulumi.get(self, "domains")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The certificate private key.
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        Geographical information.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites interface.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Certificate status.(within 30 days).- issued.- applying.- application failed.- canceled.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Certificate type. Possible values: lets_encrypt: Let's Encrypt certificate;
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WaitingRoomArgs', 'WaitingRoom']

@pulumi.input_type
class WaitingRoomArgs:
    def __init__(__self__, *,
                 cookie_name: pulumi.Input[builtins.str],
                 host_name_and_paths: pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]],
                 new_users_per_minute: pulumi.Input[builtins.str],
                 queuing_method: pulumi.Input[builtins.str],
                 queuing_status_code: pulumi.Input[builtins.str],
                 session_duration: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 status: pulumi.Input[builtins.str],
                 total_active_users: pulumi.Input[builtins.str],
                 waiting_room_name: pulumi.Input[builtins.str],
                 waiting_room_type: pulumi.Input[builtins.str],
                 custom_page_html: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disable_session_renewal_enable: Optional[pulumi.Input[builtins.str]] = None,
                 json_response_enable: Optional[pulumi.Input[builtins.str]] = None,
                 language: Optional[pulumi.Input[builtins.str]] = None,
                 queue_all_enable: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WaitingRoom resource.
        :param pulumi.Input[builtins.str] cookie_name: Custom Cookie name.
        :param pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]] host_name_and_paths: Host name and path. See `host_name_and_path` below.
        :param pulumi.Input[builtins.str] new_users_per_minute: Number of new users per minute.
        :param pulumi.Input[builtins.str] queuing_method: Way of queuing. Value:
               -'random': random.
               -'fifo': first in, first out.
               -'Passthrough ': through.
               -'Reject-all': reject all.
        :param pulumi.Input[builtins.str] queuing_status_code: Waiting room status code. Value:
               -'200'
               -'202'
               -'429'
        :param pulumi.Input[builtins.str] session_duration: Session duration in minutes.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[builtins.str] status: Waiting room enabled status. Value:
               -'on': Enable waiting room
               -'off': disabled waiting room
        :param pulumi.Input[builtins.str] total_active_users: Total number of active users.
        :param pulumi.Input[builtins.str] waiting_room_name: The name of the waiting room.
        :param pulumi.Input[builtins.str] waiting_room_type: Waiting room type, support:
               -'default': Indicates the default type.
               -'custom': indicates a custom type.
        :param pulumi.Input[builtins.str] custom_page_html: User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        :param pulumi.Input[builtins.str] description: Waiting room description.
        :param pulumi.Input[builtins.str] disable_session_renewal_enable: Disable session renewal. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] json_response_enable: The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] language: The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
               -'enus': English.
               -'zhcn': Simplified Chinese.
               -'zhhk': Traditional Chinese.
        :param pulumi.Input[builtins.str] queue_all_enable: All in line. Value:
               -'on': open.
               -'off': closed.
        """
        pulumi.set(__self__, "cookie_name", cookie_name)
        pulumi.set(__self__, "host_name_and_paths", host_name_and_paths)
        pulumi.set(__self__, "new_users_per_minute", new_users_per_minute)
        pulumi.set(__self__, "queuing_method", queuing_method)
        pulumi.set(__self__, "queuing_status_code", queuing_status_code)
        pulumi.set(__self__, "session_duration", session_duration)
        pulumi.set(__self__, "site_id", site_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "total_active_users", total_active_users)
        pulumi.set(__self__, "waiting_room_name", waiting_room_name)
        pulumi.set(__self__, "waiting_room_type", waiting_room_type)
        if custom_page_html is not None:
            pulumi.set(__self__, "custom_page_html", custom_page_html)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_session_renewal_enable is not None:
            pulumi.set(__self__, "disable_session_renewal_enable", disable_session_renewal_enable)
        if json_response_enable is not None:
            pulumi.set(__self__, "json_response_enable", json_response_enable)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if queue_all_enable is not None:
            pulumi.set(__self__, "queue_all_enable", queue_all_enable)

    @property
    @pulumi.getter(name="cookieName")
    def cookie_name(self) -> pulumi.Input[builtins.str]:
        """
        Custom Cookie name.
        """
        return pulumi.get(self, "cookie_name")

    @cookie_name.setter
    def cookie_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cookie_name", value)

    @property
    @pulumi.getter(name="hostNameAndPaths")
    def host_name_and_paths(self) -> pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]]:
        """
        Host name and path. See `host_name_and_path` below.
        """
        return pulumi.get(self, "host_name_and_paths")

    @host_name_and_paths.setter
    def host_name_and_paths(self, value: pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]]):
        pulumi.set(self, "host_name_and_paths", value)

    @property
    @pulumi.getter(name="newUsersPerMinute")
    def new_users_per_minute(self) -> pulumi.Input[builtins.str]:
        """
        Number of new users per minute.
        """
        return pulumi.get(self, "new_users_per_minute")

    @new_users_per_minute.setter
    def new_users_per_minute(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "new_users_per_minute", value)

    @property
    @pulumi.getter(name="queuingMethod")
    def queuing_method(self) -> pulumi.Input[builtins.str]:
        """
        Way of queuing. Value:
        -'random': random.
        -'fifo': first in, first out.
        -'Passthrough ': through.
        -'Reject-all': reject all.
        """
        return pulumi.get(self, "queuing_method")

    @queuing_method.setter
    def queuing_method(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "queuing_method", value)

    @property
    @pulumi.getter(name="queuingStatusCode")
    def queuing_status_code(self) -> pulumi.Input[builtins.str]:
        """
        Waiting room status code. Value:
        -'200'
        -'202'
        -'429'
        """
        return pulumi.get(self, "queuing_status_code")

    @queuing_status_code.setter
    def queuing_status_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "queuing_status_code", value)

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> pulumi.Input[builtins.str]:
        """
        Session duration in minutes.
        """
        return pulumi.get(self, "session_duration")

    @session_duration.setter
    def session_duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "session_duration", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[builtins.str]:
        """
        Waiting room enabled status. Value:
        -'on': Enable waiting room
        -'off': disabled waiting room
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="totalActiveUsers")
    def total_active_users(self) -> pulumi.Input[builtins.str]:
        """
        Total number of active users.
        """
        return pulumi.get(self, "total_active_users")

    @total_active_users.setter
    def total_active_users(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "total_active_users", value)

    @property
    @pulumi.getter(name="waitingRoomName")
    def waiting_room_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the waiting room.
        """
        return pulumi.get(self, "waiting_room_name")

    @waiting_room_name.setter
    def waiting_room_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "waiting_room_name", value)

    @property
    @pulumi.getter(name="waitingRoomType")
    def waiting_room_type(self) -> pulumi.Input[builtins.str]:
        """
        Waiting room type, support:
        -'default': Indicates the default type.
        -'custom': indicates a custom type.
        """
        return pulumi.get(self, "waiting_room_type")

    @waiting_room_type.setter
    def waiting_room_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "waiting_room_type", value)

    @property
    @pulumi.getter(name="customPageHtml")
    def custom_page_html(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        """
        return pulumi.get(self, "custom_page_html")

    @custom_page_html.setter
    def custom_page_html(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_page_html", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Waiting room description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableSessionRenewalEnable")
    def disable_session_renewal_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Disable session renewal. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "disable_session_renewal_enable")

    @disable_session_renewal_enable.setter
    def disable_session_renewal_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disable_session_renewal_enable", value)

    @property
    @pulumi.getter(name="jsonResponseEnable")
    def json_response_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "json_response_enable")

    @json_response_enable.setter
    def json_response_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "json_response_enable", value)

    @property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
        -'enus': English.
        -'zhcn': Simplified Chinese.
        -'zhhk': Traditional Chinese.
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "language", value)

    @property
    @pulumi.getter(name="queueAllEnable")
    def queue_all_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        All in line. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "queue_all_enable")

    @queue_all_enable.setter
    def queue_all_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "queue_all_enable", value)


@pulumi.input_type
class _WaitingRoomState:
    def __init__(__self__, *,
                 cookie_name: Optional[pulumi.Input[builtins.str]] = None,
                 custom_page_html: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disable_session_renewal_enable: Optional[pulumi.Input[builtins.str]] = None,
                 host_name_and_paths: Optional[pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]]] = None,
                 json_response_enable: Optional[pulumi.Input[builtins.str]] = None,
                 language: Optional[pulumi.Input[builtins.str]] = None,
                 new_users_per_minute: Optional[pulumi.Input[builtins.str]] = None,
                 queue_all_enable: Optional[pulumi.Input[builtins.str]] = None,
                 queuing_method: Optional[pulumi.Input[builtins.str]] = None,
                 queuing_status_code: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 total_active_users: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_id: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_name: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WaitingRoom resources.
        :param pulumi.Input[builtins.str] cookie_name: Custom Cookie name.
        :param pulumi.Input[builtins.str] custom_page_html: User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        :param pulumi.Input[builtins.str] description: Waiting room description.
        :param pulumi.Input[builtins.str] disable_session_renewal_enable: Disable session renewal. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]] host_name_and_paths: Host name and path. See `host_name_and_path` below.
        :param pulumi.Input[builtins.str] json_response_enable: The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] language: The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
               -'enus': English.
               -'zhcn': Simplified Chinese.
               -'zhhk': Traditional Chinese.
        :param pulumi.Input[builtins.str] new_users_per_minute: Number of new users per minute.
        :param pulumi.Input[builtins.str] queue_all_enable: All in line. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] queuing_method: Way of queuing. Value:
               -'random': random.
               -'fifo': first in, first out.
               -'Passthrough ': through.
               -'Reject-all': reject all.
        :param pulumi.Input[builtins.str] queuing_status_code: Waiting room status code. Value:
               -'200'
               -'202'
               -'429'
        :param pulumi.Input[builtins.str] session_duration: Session duration in minutes.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[builtins.str] status: Waiting room enabled status. Value:
               -'on': Enable waiting room
               -'off': disabled waiting room
        :param pulumi.Input[builtins.str] total_active_users: Total number of active users.
        :param pulumi.Input[builtins.str] waiting_room_id: The waiting room ID, which can be obtained by calling the [ListWaitingRooms](https://help.aliyun.com/document_detail/2850279.html) API.
        :param pulumi.Input[builtins.str] waiting_room_name: The name of the waiting room.
        :param pulumi.Input[builtins.str] waiting_room_type: Waiting room type, support:
               -'default': Indicates the default type.
               -'custom': indicates a custom type.
        """
        if cookie_name is not None:
            pulumi.set(__self__, "cookie_name", cookie_name)
        if custom_page_html is not None:
            pulumi.set(__self__, "custom_page_html", custom_page_html)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_session_renewal_enable is not None:
            pulumi.set(__self__, "disable_session_renewal_enable", disable_session_renewal_enable)
        if host_name_and_paths is not None:
            pulumi.set(__self__, "host_name_and_paths", host_name_and_paths)
        if json_response_enable is not None:
            pulumi.set(__self__, "json_response_enable", json_response_enable)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if new_users_per_minute is not None:
            pulumi.set(__self__, "new_users_per_minute", new_users_per_minute)
        if queue_all_enable is not None:
            pulumi.set(__self__, "queue_all_enable", queue_all_enable)
        if queuing_method is not None:
            pulumi.set(__self__, "queuing_method", queuing_method)
        if queuing_status_code is not None:
            pulumi.set(__self__, "queuing_status_code", queuing_status_code)
        if session_duration is not None:
            pulumi.set(__self__, "session_duration", session_duration)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if total_active_users is not None:
            pulumi.set(__self__, "total_active_users", total_active_users)
        if waiting_room_id is not None:
            pulumi.set(__self__, "waiting_room_id", waiting_room_id)
        if waiting_room_name is not None:
            pulumi.set(__self__, "waiting_room_name", waiting_room_name)
        if waiting_room_type is not None:
            pulumi.set(__self__, "waiting_room_type", waiting_room_type)

    @property
    @pulumi.getter(name="cookieName")
    def cookie_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom Cookie name.
        """
        return pulumi.get(self, "cookie_name")

    @cookie_name.setter
    def cookie_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cookie_name", value)

    @property
    @pulumi.getter(name="customPageHtml")
    def custom_page_html(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        """
        return pulumi.get(self, "custom_page_html")

    @custom_page_html.setter
    def custom_page_html(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_page_html", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Waiting room description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableSessionRenewalEnable")
    def disable_session_renewal_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Disable session renewal. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "disable_session_renewal_enable")

    @disable_session_renewal_enable.setter
    def disable_session_renewal_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disable_session_renewal_enable", value)

    @property
    @pulumi.getter(name="hostNameAndPaths")
    def host_name_and_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]]]:
        """
        Host name and path. See `host_name_and_path` below.
        """
        return pulumi.get(self, "host_name_and_paths")

    @host_name_and_paths.setter
    def host_name_and_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WaitingRoomHostNameAndPathArgs']]]]):
        pulumi.set(self, "host_name_and_paths", value)

    @property
    @pulumi.getter(name="jsonResponseEnable")
    def json_response_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "json_response_enable")

    @json_response_enable.setter
    def json_response_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "json_response_enable", value)

    @property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
        -'enus': English.
        -'zhcn': Simplified Chinese.
        -'zhhk': Traditional Chinese.
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "language", value)

    @property
    @pulumi.getter(name="newUsersPerMinute")
    def new_users_per_minute(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Number of new users per minute.
        """
        return pulumi.get(self, "new_users_per_minute")

    @new_users_per_minute.setter
    def new_users_per_minute(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_users_per_minute", value)

    @property
    @pulumi.getter(name="queueAllEnable")
    def queue_all_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        All in line. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "queue_all_enable")

    @queue_all_enable.setter
    def queue_all_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "queue_all_enable", value)

    @property
    @pulumi.getter(name="queuingMethod")
    def queuing_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Way of queuing. Value:
        -'random': random.
        -'fifo': first in, first out.
        -'Passthrough ': through.
        -'Reject-all': reject all.
        """
        return pulumi.get(self, "queuing_method")

    @queuing_method.setter
    def queuing_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "queuing_method", value)

    @property
    @pulumi.getter(name="queuingStatusCode")
    def queuing_status_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Waiting room status code. Value:
        -'200'
        -'202'
        -'429'
        """
        return pulumi.get(self, "queuing_status_code")

    @queuing_status_code.setter
    def queuing_status_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "queuing_status_code", value)

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Session duration in minutes.
        """
        return pulumi.get(self, "session_duration")

    @session_duration.setter
    def session_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "session_duration", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Waiting room enabled status. Value:
        -'on': Enable waiting room
        -'off': disabled waiting room
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="totalActiveUsers")
    def total_active_users(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Total number of active users.
        """
        return pulumi.get(self, "total_active_users")

    @total_active_users.setter
    def total_active_users(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "total_active_users", value)

    @property
    @pulumi.getter(name="waitingRoomId")
    def waiting_room_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The waiting room ID, which can be obtained by calling the [ListWaitingRooms](https://help.aliyun.com/document_detail/2850279.html) API.
        """
        return pulumi.get(self, "waiting_room_id")

    @waiting_room_id.setter
    def waiting_room_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waiting_room_id", value)

    @property
    @pulumi.getter(name="waitingRoomName")
    def waiting_room_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the waiting room.
        """
        return pulumi.get(self, "waiting_room_name")

    @waiting_room_name.setter
    def waiting_room_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waiting_room_name", value)

    @property
    @pulumi.getter(name="waitingRoomType")
    def waiting_room_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Waiting room type, support:
        -'default': Indicates the default type.
        -'custom': indicates a custom type.
        """
        return pulumi.get(self, "waiting_room_type")

    @waiting_room_type.setter
    def waiting_room_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "waiting_room_type", value)


@pulumi.type_token("alicloud:esa/waitingRoom:WaitingRoom")
class WaitingRoom(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cookie_name: Optional[pulumi.Input[builtins.str]] = None,
                 custom_page_html: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disable_session_renewal_enable: Optional[pulumi.Input[builtins.str]] = None,
                 host_name_and_paths: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WaitingRoomHostNameAndPathArgs', 'WaitingRoomHostNameAndPathArgsDict']]]]] = None,
                 json_response_enable: Optional[pulumi.Input[builtins.str]] = None,
                 language: Optional[pulumi.Input[builtins.str]] = None,
                 new_users_per_minute: Optional[pulumi.Input[builtins.str]] = None,
                 queue_all_enable: Optional[pulumi.Input[builtins.str]] = None,
                 queuing_method: Optional[pulumi.Input[builtins.str]] = None,
                 queuing_status_code: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 total_active_users: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_name: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Waiting Room resource.

        For information about ESA Waiting Room and how to use it, see [What is Waiting Room](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateWaitingRoom).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        resource_site_example = alicloud.esa.Site("resource_Site_example",
            site_name="terraform.site",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_waiting_room = alicloud.esa.WaitingRoom("default",
            queuing_method="fifo",
            session_duration="5",
            total_active_users="300",
            host_name_and_paths=[
                {
                    "domain": "sub_domain.com",
                    "path": "/example",
                    "subdomain": "example_sub_domain.com.",
                },
                {
                    "domain": "sub_domain.com",
                    "path": "/example",
                    "subdomain": "example_sub_domain1.com.",
                },
                {
                    "path": "/example",
                    "subdomain": "example_sub_domain2.com.",
                    "domain": "sub_domain.com",
                },
            ],
            waiting_room_type="default",
            new_users_per_minute="200",
            custom_page_html="",
            language="zhcn",
            queuing_status_code="200",
            waiting_room_name="waitingroom_example",
            status="off",
            site_id=resource_site_example.id,
            queue_all_enable="off",
            disable_session_renewal_enable="off",
            description="example",
            json_response_enable="off",
            cookie_name="__aliwaitingroom_example")
        ```

        ## Import

        ESA Waiting Room can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/waitingRoom:WaitingRoom example <site_id>:<waiting_room_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cookie_name: Custom Cookie name.
        :param pulumi.Input[builtins.str] custom_page_html: User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        :param pulumi.Input[builtins.str] description: Waiting room description.
        :param pulumi.Input[builtins.str] disable_session_renewal_enable: Disable session renewal. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WaitingRoomHostNameAndPathArgs', 'WaitingRoomHostNameAndPathArgsDict']]]] host_name_and_paths: Host name and path. See `host_name_and_path` below.
        :param pulumi.Input[builtins.str] json_response_enable: The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] language: The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
               -'enus': English.
               -'zhcn': Simplified Chinese.
               -'zhhk': Traditional Chinese.
        :param pulumi.Input[builtins.str] new_users_per_minute: Number of new users per minute.
        :param pulumi.Input[builtins.str] queue_all_enable: All in line. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] queuing_method: Way of queuing. Value:
               -'random': random.
               -'fifo': first in, first out.
               -'Passthrough ': through.
               -'Reject-all': reject all.
        :param pulumi.Input[builtins.str] queuing_status_code: Waiting room status code. Value:
               -'200'
               -'202'
               -'429'
        :param pulumi.Input[builtins.str] session_duration: Session duration in minutes.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[builtins.str] status: Waiting room enabled status. Value:
               -'on': Enable waiting room
               -'off': disabled waiting room
        :param pulumi.Input[builtins.str] total_active_users: Total number of active users.
        :param pulumi.Input[builtins.str] waiting_room_name: The name of the waiting room.
        :param pulumi.Input[builtins.str] waiting_room_type: Waiting room type, support:
               -'default': Indicates the default type.
               -'custom': indicates a custom type.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WaitingRoomArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Waiting Room resource.

        For information about ESA Waiting Room and how to use it, see [What is Waiting Room](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateWaitingRoom).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        resource_site_example = alicloud.esa.Site("resource_Site_example",
            site_name="terraform.site",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_waiting_room = alicloud.esa.WaitingRoom("default",
            queuing_method="fifo",
            session_duration="5",
            total_active_users="300",
            host_name_and_paths=[
                {
                    "domain": "sub_domain.com",
                    "path": "/example",
                    "subdomain": "example_sub_domain.com.",
                },
                {
                    "domain": "sub_domain.com",
                    "path": "/example",
                    "subdomain": "example_sub_domain1.com.",
                },
                {
                    "path": "/example",
                    "subdomain": "example_sub_domain2.com.",
                    "domain": "sub_domain.com",
                },
            ],
            waiting_room_type="default",
            new_users_per_minute="200",
            custom_page_html="",
            language="zhcn",
            queuing_status_code="200",
            waiting_room_name="waitingroom_example",
            status="off",
            site_id=resource_site_example.id,
            queue_all_enable="off",
            disable_session_renewal_enable="off",
            description="example",
            json_response_enable="off",
            cookie_name="__aliwaitingroom_example")
        ```

        ## Import

        ESA Waiting Room can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/waitingRoom:WaitingRoom example <site_id>:<waiting_room_id>
        ```

        :param str resource_name: The name of the resource.
        :param WaitingRoomArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WaitingRoomArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cookie_name: Optional[pulumi.Input[builtins.str]] = None,
                 custom_page_html: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disable_session_renewal_enable: Optional[pulumi.Input[builtins.str]] = None,
                 host_name_and_paths: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WaitingRoomHostNameAndPathArgs', 'WaitingRoomHostNameAndPathArgsDict']]]]] = None,
                 json_response_enable: Optional[pulumi.Input[builtins.str]] = None,
                 language: Optional[pulumi.Input[builtins.str]] = None,
                 new_users_per_minute: Optional[pulumi.Input[builtins.str]] = None,
                 queue_all_enable: Optional[pulumi.Input[builtins.str]] = None,
                 queuing_method: Optional[pulumi.Input[builtins.str]] = None,
                 queuing_status_code: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 total_active_users: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_name: Optional[pulumi.Input[builtins.str]] = None,
                 waiting_room_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WaitingRoomArgs.__new__(WaitingRoomArgs)

            if cookie_name is None and not opts.urn:
                raise TypeError("Missing required property 'cookie_name'")
            __props__.__dict__["cookie_name"] = cookie_name
            __props__.__dict__["custom_page_html"] = custom_page_html
            __props__.__dict__["description"] = description
            __props__.__dict__["disable_session_renewal_enable"] = disable_session_renewal_enable
            if host_name_and_paths is None and not opts.urn:
                raise TypeError("Missing required property 'host_name_and_paths'")
            __props__.__dict__["host_name_and_paths"] = host_name_and_paths
            __props__.__dict__["json_response_enable"] = json_response_enable
            __props__.__dict__["language"] = language
            if new_users_per_minute is None and not opts.urn:
                raise TypeError("Missing required property 'new_users_per_minute'")
            __props__.__dict__["new_users_per_minute"] = new_users_per_minute
            __props__.__dict__["queue_all_enable"] = queue_all_enable
            if queuing_method is None and not opts.urn:
                raise TypeError("Missing required property 'queuing_method'")
            __props__.__dict__["queuing_method"] = queuing_method
            if queuing_status_code is None and not opts.urn:
                raise TypeError("Missing required property 'queuing_status_code'")
            __props__.__dict__["queuing_status_code"] = queuing_status_code
            if session_duration is None and not opts.urn:
                raise TypeError("Missing required property 'session_duration'")
            __props__.__dict__["session_duration"] = session_duration
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            if total_active_users is None and not opts.urn:
                raise TypeError("Missing required property 'total_active_users'")
            __props__.__dict__["total_active_users"] = total_active_users
            if waiting_room_name is None and not opts.urn:
                raise TypeError("Missing required property 'waiting_room_name'")
            __props__.__dict__["waiting_room_name"] = waiting_room_name
            if waiting_room_type is None and not opts.urn:
                raise TypeError("Missing required property 'waiting_room_type'")
            __props__.__dict__["waiting_room_type"] = waiting_room_type
            __props__.__dict__["waiting_room_id"] = None
        super(WaitingRoom, __self__).__init__(
            'alicloud:esa/waitingRoom:WaitingRoom',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cookie_name: Optional[pulumi.Input[builtins.str]] = None,
            custom_page_html: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            disable_session_renewal_enable: Optional[pulumi.Input[builtins.str]] = None,
            host_name_and_paths: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WaitingRoomHostNameAndPathArgs', 'WaitingRoomHostNameAndPathArgsDict']]]]] = None,
            json_response_enable: Optional[pulumi.Input[builtins.str]] = None,
            language: Optional[pulumi.Input[builtins.str]] = None,
            new_users_per_minute: Optional[pulumi.Input[builtins.str]] = None,
            queue_all_enable: Optional[pulumi.Input[builtins.str]] = None,
            queuing_method: Optional[pulumi.Input[builtins.str]] = None,
            queuing_status_code: Optional[pulumi.Input[builtins.str]] = None,
            session_duration: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            total_active_users: Optional[pulumi.Input[builtins.str]] = None,
            waiting_room_id: Optional[pulumi.Input[builtins.str]] = None,
            waiting_room_name: Optional[pulumi.Input[builtins.str]] = None,
            waiting_room_type: Optional[pulumi.Input[builtins.str]] = None) -> 'WaitingRoom':
        """
        Get an existing WaitingRoom resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cookie_name: Custom Cookie name.
        :param pulumi.Input[builtins.str] custom_page_html: User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        :param pulumi.Input[builtins.str] description: Waiting room description.
        :param pulumi.Input[builtins.str] disable_session_renewal_enable: Disable session renewal. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WaitingRoomHostNameAndPathArgs', 'WaitingRoomHostNameAndPathArgsDict']]]] host_name_and_paths: Host name and path. See `host_name_and_path` below.
        :param pulumi.Input[builtins.str] json_response_enable: The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] language: The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
               -'enus': English.
               -'zhcn': Simplified Chinese.
               -'zhhk': Traditional Chinese.
        :param pulumi.Input[builtins.str] new_users_per_minute: Number of new users per minute.
        :param pulumi.Input[builtins.str] queue_all_enable: All in line. Value:
               -'on': open.
               -'off': closed.
        :param pulumi.Input[builtins.str] queuing_method: Way of queuing. Value:
               -'random': random.
               -'fifo': first in, first out.
               -'Passthrough ': through.
               -'Reject-all': reject all.
        :param pulumi.Input[builtins.str] queuing_status_code: Waiting room status code. Value:
               -'200'
               -'202'
               -'429'
        :param pulumi.Input[builtins.str] session_duration: Session duration in minutes.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[builtins.str] status: Waiting room enabled status. Value:
               -'on': Enable waiting room
               -'off': disabled waiting room
        :param pulumi.Input[builtins.str] total_active_users: Total number of active users.
        :param pulumi.Input[builtins.str] waiting_room_id: The waiting room ID, which can be obtained by calling the [ListWaitingRooms](https://help.aliyun.com/document_detail/2850279.html) API.
        :param pulumi.Input[builtins.str] waiting_room_name: The name of the waiting room.
        :param pulumi.Input[builtins.str] waiting_room_type: Waiting room type, support:
               -'default': Indicates the default type.
               -'custom': indicates a custom type.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WaitingRoomState.__new__(_WaitingRoomState)

        __props__.__dict__["cookie_name"] = cookie_name
        __props__.__dict__["custom_page_html"] = custom_page_html
        __props__.__dict__["description"] = description
        __props__.__dict__["disable_session_renewal_enable"] = disable_session_renewal_enable
        __props__.__dict__["host_name_and_paths"] = host_name_and_paths
        __props__.__dict__["json_response_enable"] = json_response_enable
        __props__.__dict__["language"] = language
        __props__.__dict__["new_users_per_minute"] = new_users_per_minute
        __props__.__dict__["queue_all_enable"] = queue_all_enable
        __props__.__dict__["queuing_method"] = queuing_method
        __props__.__dict__["queuing_status_code"] = queuing_status_code
        __props__.__dict__["session_duration"] = session_duration
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["status"] = status
        __props__.__dict__["total_active_users"] = total_active_users
        __props__.__dict__["waiting_room_id"] = waiting_room_id
        __props__.__dict__["waiting_room_name"] = waiting_room_name
        __props__.__dict__["waiting_room_type"] = waiting_room_type
        return WaitingRoom(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cookieName")
    def cookie_name(self) -> pulumi.Output[builtins.str]:
        """
        Custom Cookie name.
        """
        return pulumi.get(self, "cookie_name")

    @property
    @pulumi.getter(name="customPageHtml")
    def custom_page_html(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        User-defined waiting room page content, when the waiting room type is custom type, you need to enter. The incoming content needs to be base64 encoded.
        """
        return pulumi.get(self, "custom_page_html")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Waiting room description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="disableSessionRenewalEnable")
    def disable_session_renewal_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Disable session renewal. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "disable_session_renewal_enable")

    @property
    @pulumi.getter(name="hostNameAndPaths")
    def host_name_and_paths(self) -> pulumi.Output[Sequence['outputs.WaitingRoomHostNameAndPath']]:
        """
        Host name and path. See `host_name_and_path` below.
        """
        return pulumi.get(self, "host_name_and_paths")

    @property
    @pulumi.getter(name="jsonResponseEnable")
    def json_response_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The JSON response. If the accept request header contains "application/json", JSON data is returned. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "json_response_enable")

    @property
    @pulumi.getter
    def language(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The language of the waiting room page. When the waiting room type is the default type, it needs to be passed in. The following types are supported:
        -'enus': English.
        -'zhcn': Simplified Chinese.
        -'zhhk': Traditional Chinese.
        """
        return pulumi.get(self, "language")

    @property
    @pulumi.getter(name="newUsersPerMinute")
    def new_users_per_minute(self) -> pulumi.Output[builtins.str]:
        """
        Number of new users per minute.
        """
        return pulumi.get(self, "new_users_per_minute")

    @property
    @pulumi.getter(name="queueAllEnable")
    def queue_all_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        All in line. Value:
        -'on': open.
        -'off': closed.
        """
        return pulumi.get(self, "queue_all_enable")

    @property
    @pulumi.getter(name="queuingMethod")
    def queuing_method(self) -> pulumi.Output[builtins.str]:
        """
        Way of queuing. Value:
        -'random': random.
        -'fifo': first in, first out.
        -'Passthrough ': through.
        -'Reject-all': reject all.
        """
        return pulumi.get(self, "queuing_method")

    @property
    @pulumi.getter(name="queuingStatusCode")
    def queuing_status_code(self) -> pulumi.Output[builtins.str]:
        """
        Waiting room status code. Value:
        -'200'
        -'202'
        -'429'
        """
        return pulumi.get(self, "queuing_status_code")

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> pulumi.Output[builtins.str]:
        """
        Session duration in minutes.
        """
        return pulumi.get(self, "session_duration")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Waiting room enabled status. Value:
        -'on': Enable waiting room
        -'off': disabled waiting room
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="totalActiveUsers")
    def total_active_users(self) -> pulumi.Output[builtins.str]:
        """
        Total number of active users.
        """
        return pulumi.get(self, "total_active_users")

    @property
    @pulumi.getter(name="waitingRoomId")
    def waiting_room_id(self) -> pulumi.Output[builtins.str]:
        """
        The waiting room ID, which can be obtained by calling the [ListWaitingRooms](https://help.aliyun.com/document_detail/2850279.html) API.
        """
        return pulumi.get(self, "waiting_room_id")

    @property
    @pulumi.getter(name="waitingRoomName")
    def waiting_room_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the waiting room.
        """
        return pulumi.get(self, "waiting_room_name")

    @property
    @pulumi.getter(name="waitingRoomType")
    def waiting_room_type(self) -> pulumi.Output[builtins.str]:
        """
        Waiting room type, support:
        -'default': Indicates the default type.
        -'custom': indicates a custom type.
        """
        return pulumi.get(self, "waiting_room_type")

